;(function(){
(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(['exports', 'element-ui', '../_style/global.css', './style/index.css'], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require('element-ui'), require('../_style/global.css'), require('./style/index.css'));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.elementUi, global.global, global.index);
    global.index = mod.exports;
  }
})(this, function (exports, _elementUi) {
  'use strict';

  Object.defineProperty(exports, "__esModule", {
    value: true
  });

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }

    return obj;
  }

  exports.default = {
    name: 'FormJsx',
    components: {
      Form: _elementUi.Form,
      FormItem: _elementUi.FormItem,
      Input: _elementUi.Input,
      Radio: _elementUi.Radio,
      DatePicker: _elementUi.DatePicker,
      InputNumber: _elementUi.InputNumber,
      ColorPicker: _elementUi.ColorPicker,
      Select: _elementUi.Select
    },
    props: {
      labelWidth: {
        type: String,
        default: '120px'
      },
      items: {
        type: Array,
        default: function _default() {
          return [];
        }
      },
      formData: {
        type: Object,
        default: function _default() {}
      }
    },
    data: function data() {
      return {
        form: this.formData
      };
    },

    computed: {
      rules: function rules() {
        return this.items.reduce(function (map, item) {
          if (item.rules) {
            map[item.prop] = item.rules;
          }
          return map;
        }, {});
      }
    },
    methods: {
      change: function change(key, value) {
        this.form = Object.assign({}, this.form, _defineProperty({}, key, value));
      },
      validate: function validate() {
        var _this = this;

        return new Promise(function (resolve, reject) {
          _this.$refs.form.validate(function (valid) {
            if (valid) {
              resolve();
            } else {
              reject();
            }
          });
        });
      },
      resetForm: function resetForm() {
        this.$refs.form.resetFields();
      },
      clearValidate: function clearValidate() {
        this.$refs.form.clearValidate();
      }
    },
    render: function render(h) {
      var _this2 = this;

      var items = this.items,
          labelWidth = this.labelWidth,
          form = this.form;

      var componentMap = {
        input: function input(item) {
          return h('el-input', {
            attrs: {
              attrs: item.props,
              value: form[item.prop]
            },
            on: {
              'input': function input(value) {
                return _this2.change(item.prop, value);
              }
            }
          });
        },
        number: function number(item) {
          return h('el-inputNumber', {
            attrs: {
              attrs: item.props,
              value: form[item.prop]
            },
            on: {
              'input': function input(value) {
                return _this2.change(item.prop, value);
              }
            }
          });
        },
        colorPicker: function colorPicker(item) {
          return h('el-color-picker', {
            attrs: {
              attrs: item.props,
              value: form[item.prop]
            },
            on: {
              'input': function input(value) {
                return _this2.change(item.prop, value);
              }
            }
          });
        },
        date: function date(item) {
          return h('el-date-picker', {
            attrs: {
              attrs: item.props,
              value: form[item.prop]
            },
            on: {
              'input': _this2.change.bind(_this2, item.prop)
            }
          });
        },
        radio: function radio(item) {
          return item.props.list && item.props.list.map(function (d, idx) {
            return h(
              'el-radio',
              {
                attrs: {
                  attrs: item.props,
                  value: form[item.prop],

                  label: d.label
                },
                key: idx, on: {
                  'input': _this2.change.bind(_this2, item.prop)
                }
              },
              [d.value]
            );
          });
        },
        slot: function slot(item) {
          var slotName = item.slotName;

          var slot = _this2.$slots[slotName];
          return h('div', [slot]);
        }
      };
      return h(
        'el-form',
        {
          attrs: {
            labelWidth: labelWidth,
            attrs: { model: form },
            rules: this.rules
          },
          ref: 'form'
        },
        [items.map(function (item, idx) {
          return h(
            'el-form-item',
            {
              key: idx,
              attrs: { label: item.label,
                prop: item.prop,
                labelWidth: labelWidth
              }
            },
            [componentMap[item.pattern](item)]
          );
        })]
      );
    }
  };
});
})()
if (module.exports.__esModule) module.exports = module.exports.default
var __vue__options__ = (typeof module.exports === "function"? module.exports.options: module.exports)
